..  sphinx-include-summary-start

=====
Flopi
=====

Flopi is a fine-grained logging and output Python interface for
displaying and recording status, event, debugging, warning, and error
information. In the future, Flopi will be able to operate as a pure
Python module, or in conjunction with `Flout`_ when `extending or
embedding`_ the Python interpreter.

`Flopi`_ is part of the `Code Craftsmen`_ project.  The
`documentation`_ is hosted on `Read the Docs`_ and the `source code`_
can be found on `GitHub`_.

.. _Flout: https://www.codecraftsmen.org/software.html#flout
.. _extending or embedding: https://docs.python.org/3/extending
.. _Flopi: https://www.codecraftsmen.org/software.html#flopi
.. _Code Craftsmen: https://www.codecraftsmen.org
.. _documentation: https://flopi.readthedocs.io
.. _Read the Docs: https://www.codecraftsmen.org/foundation.html#read-the-docs
.. _source code: https://github.com/codecraftingtools/flopi
.. _GitHub: https://www.codecraftsmen.org/foundation.html#github

..  sphinx-include-summary-end
